import { SocketDtoDirectionEnum, SocketDtoTypeEnum } from '@smallstack/axios-api-client';
import { BooleanEquationOperator } from '@smallstack/utils';
import { WidgetTag } from '@smallstack/widget-core';
import { a as SocketNames } from './smallstack-data-widgets-smallstack-data-widgets-5b213b80.mjs';
import '@smallstack/form-core-components';

var DataTableV3RenderTypes;
(function (DataTableV3RenderTypes) {
    DataTableV3RenderTypes["RAW"] = "raw";
    DataTableV3RenderTypes["I18N"] = "i18n";
    DataTableV3RenderTypes["ICON"] = "icon";
    DataTableV3RenderTypes["IMAGE"] = "image";
    DataTableV3RenderTypes["DATE"] = "date";
    DataTableV3RenderTypes["DURATION"] = "duration";
    DataTableV3RenderTypes["STORE_PROPERTY"] = "storeProperty";
    DataTableV3RenderTypes["QR_CODE"] = "qrCode";
    DataTableV3RenderTypes["DIALOG"] = "dialog";
    DataTableV3RenderTypes["LINK"] = "link";
    DataTableV3RenderTypes["BOOLEAN"] = "boolean";
    DataTableV3RenderTypes["MARKDOWN"] = "markdown";
    DataTableV3RenderTypes["GOOGLE_MAP"] = "googleMap";
    DataTableV3RenderTypes["WIDGET"] = "widget";
    DataTableV3RenderTypes["CURRENCY"] = "currency";
    DataTableV3RenderTypes["VALUE_MAPPING"] = "valueMapping";
})(DataTableV3RenderTypes || (DataTableV3RenderTypes = {}));
const sockets = [
    { direction: SocketDtoDirectionEnum.In, name: SocketNames.DATA, type: SocketDtoTypeEnum.Objectarray }
];
const DataTableV3Configuration = {
    templateName: "Offline Daten Tabelle",
    icon: "gantt-chart",
    templateDescription: "Zeigt Daten in einer Tabelle an. Kann mit Editoren oder Detail Ansichten erweitert werden.",
    dataSchema: {
        type: "object",
        properties: {
            typeName: {
                title: "Datentyp",
                type: "string",
                description: "Der Datentyp bestimmt, welche Editoren angezeigt werden, falls Daten editiert werden sollen.",
                "x-schema-form": { widget: "types", usePlural: true }
            },
            listProperties: {
                title: "Tabellenspalten",
                description: "Welche Eigenschaften sollen in der Tabelle angezeigt werden?",
                type: "array",
                items: {
                    type: "object",
                    properties: {
                        property: {
                            type: "string",
                            title: "Name der Eigenschaft",
                            "x-schema-form": {
                                widget: "SchemaPropertySelector",
                                typeNameProperty: "typeName"
                            }
                        },
                        title: {
                            type: "array",
                            title: "Spaltenüberschrift",
                            "x-schema-form": { widget: "i18n" }
                        },
                        sortable: { type: "boolean", title: "Sortierbar" },
                        renderer: {
                            type: "string",
                            enum: Object.values(DataTableV3RenderTypes),
                            title: "Anzeigeform",
                            "x-i18n-prefix": "@@widgets.dataTable.renderTypes."
                        },
                        i18nPrefix: {
                            type: "string",
                            title: "Prefix",
                            description: "Ein Prefix für den I18n Schlüssel",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.I18N
                                        }
                                    }
                                ]
                            }
                        },
                        valueIconPairArray: {
                            type: "array",
                            items: {
                                type: "object",
                                properties: {
                                    value: {
                                        type: "string",
                                        title: "Wert"
                                    },
                                    icon: {
                                        type: "string",
                                        title: "Icon",
                                        "x-schema-form": {
                                            widget: "icon"
                                        }
                                    }
                                }
                            },
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.ICON
                                        }
                                    }
                                ]
                            }
                        },
                        mappingArray: {
                            type: "array",
                            items: {
                                type: "object",
                                properties: {
                                    value: {
                                        type: "string",
                                        title: "Startwert"
                                    },
                                    mappedValue: {
                                        type: "string",
                                        title: "Zielwert"
                                    }
                                }
                            },
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.VALUE_MAPPING
                                        }
                                    }
                                ]
                            }
                        },
                        rendererDateFormat: {
                            type: "string",
                            enum: ["short", "shortDate", "shortTime"],
                            title: "Datum Format",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.DATE
                                        }
                                    }
                                ]
                            }
                        },
                        rendererStorePropertyStore: {
                            type: "string",
                            title: "Store",
                            "x-schema-form": {
                                widget: "stores",
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.STORE_PROPERTY
                                        }
                                    }
                                ]
                            }
                        },
                        rendererStorePropertyProperty: {
                            type: "string",
                            title: "Anzeigeeigenschaft",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.STORE_PROPERTY
                                        }
                                    }
                                ]
                            }
                        },
                        googleMapsPreviewHeight: {
                            type: "number",
                            title: "Vorschau Höhe",
                            default: 80,
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.GOOGLE_MAP
                                        }
                                    }
                                ]
                            }
                        },
                        googleMapsPreviewWidth: {
                            type: "number",
                            title: "Vorschau Breite",
                            default: 120,
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.GOOGLE_MAP
                                        }
                                    }
                                ]
                            }
                        },
                        qrCodePrefix: {
                            type: "string",
                            title: "QR Code Prefix",
                            description: "Kann zum Beispiel eine URL sein. Der angegebene Eigenschaftswert wird hinten angehängt.",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.QR_CODE
                                        }
                                    }
                                ]
                            }
                        },
                        dialogWidth: {
                            type: "string",
                            title: "Dialog Breite in %, px oder vw",
                            default: "600px",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.DIALOG
                                        }
                                    }
                                ]
                            }
                        },
                        dialogHeight: {
                            type: "string",
                            title: "Dialog Höhe in %, px oder vh",
                            default: "600px",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.DIALOG
                                        }
                                    }
                                ]
                            }
                        },
                        dialogButtonIcon: {
                            type: "string",
                            title: "Icon auf dem Button",
                            default: "search",
                            "x-schema-form": {
                                widget: "icon",
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.DIALOG
                                        }
                                    }
                                ]
                            }
                        },
                        dialogUrlSyncParameter: {
                            type: "string",
                            title: "Url Sync Parameter",
                            description: "Synchronisiert geöffnete Dialoge über die Url",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.DIALOG
                                        }
                                    }
                                ]
                            }
                        },
                        linkLabel: {
                            type: "string",
                            title: "Link Label",
                            description: "Definierbarer Text für den Link.",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.LINK
                                        }
                                    }
                                ]
                            }
                        },
                        openLinkInNewWindow: {
                            type: "boolean",
                            title: "Link in einem neuen Fenster öffnen?",
                            "x-schema-form": {
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.LINK
                                        }
                                    }
                                ]
                            }
                        },
                        widget: {
                            type: "string",
                            title: "Komponenten",
                            description: "Definieren Sie die Komponente, welche angezeigt werden soll.",
                            "x-schema-form": {
                                widget: "cms",
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.WIDGET
                                        }
                                    }
                                ]
                            }
                        },
                        widgetContextType: {
                            type: "string",
                            title: "Widget Kontext",
                            description: "Wählen Sie, ob die komplette Entität auf dem Kontext verfügbar sein soll oder nur die aktuelle Eigenschaft. Im Global Store wird immer das komplette Model verfügbar sein.",
                            enum: ["property", "full"],
                            default: "property",
                            "x-schema-form": {
                                widget: "cms",
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.WIDGET
                                        }
                                    }
                                ]
                            }
                        },
                        currency: {
                            type: "string",
                            title: "Währung",
                            "x-schema-form": {
                                widget: "Select",
                                values: [
                                    { label: "EUR", value: "EUR" },
                                    { label: "USD", value: "USD" }
                                ],
                                rules: [
                                    {
                                        action: "hide",
                                        if: {
                                            dataPath: "../renderer",
                                            operator: BooleanEquationOperator.NOT_EQUALS,
                                            value: DataTableV3RenderTypes.CURRENCY
                                        }
                                    }
                                ]
                            }
                        }
                    },
                    required: ["title", "property"]
                }
            },
            showEditButton: {
                title: "Bearbeiten",
                description: "Soll ein Bearbeiten Button in der Liste angezeigt werden?",
                type: "boolean",
                default: true
            },
            showDeleteButton: {
                title: "Löschen",
                description: "Soll ein Löschen Button in der Liste angezeigt werden?",
                type: "boolean",
                default: true
            },
            allowMultiDelete: {
                title: "Mehrfach Löschung",
                description: "Soll es möglich sein, mittels Mehrfachauswahl mehrere Einträge gleichzeitig zu löschen?",
                type: "boolean",
                default: false
            },
            showCreateButton: {
                title: "Erstellen",
                description: "Soll ein Erstellen Button unter der Liste angezeigt werden?",
                type: "boolean",
                default: true
            },
            showCheckboxes: {
                title: "Zeige Checkboxen",
                description: "Zeige Checkboxen vor jeder Reihe",
                type: "boolean",
                default: false
            },
            autoSortProperty: {
                title: "Automatisch Sortieren",
                description: "Geben Sie eine Eigenschaft an, nach der automatisch sortiert werden soll. Verwenden Sie ein Minus für umgekehrte Sortierung. Beispiele: createdAt, -createdAt, name or -age",
                type: "string"
            }
        }
    },
    tags: [WidgetTag.CMS, WidgetTag.CBO, WidgetTag.APPLICATION, WidgetTag.PROJECT_DASHBOARD],
    sockets
};

export { DataTableV3Configuration, DataTableV3RenderTypes, sockets };
//# sourceMappingURL=smallstack-data-widgets-data-table-v3-widget-configuration-b3b6a9c9.mjs.map
